/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const projectsData = [
  { id: 0, title: 'GL PRJ 3E4', value: 938191 },
  { id: 1, title: 'GL PRJ GG3', value: 23123 },
  { id: 2, title: 'GL PRJ 1XX', value: 653241 },
  { id: 3, title: 'GL PRJ 2X8', value: 1112 },
  { id: 4, title: 'GL PRJ 3FG', value: 51251251 },
  { id: 5, title: 'GL PRJ 789', value: 1211 },
  { id: 6, title: 'GL PRJ 22E', value: 34168 },
  { id: 7, title: 'GL PRJ 98Z', value: 9877673 },
  { id: 8, title: 'GL PRJ RR5', value: 657493 }
]

export { projectsData }
